@@ -32,7 +32,7 @@ class PipeFollower(threading.Thread):
                                 lines += r
                                 while b"\n" in lines:
                                     line, lines = lines.split(b"\n", 1)
-                                    self.logger.info("%s", str(line))
+                                    self.logger.info("%s", line.decode())
                             elif mask & select.POLLHUP:
                                 self.logger.debug("Hang up")
                                 return
